@@ -45,7 +45,7 @@ class VkontakteManager(models.Manager):
         '''
         Return vkonakte object by url
         '''
-        m = re.findall(r'(?:http://)?vk.com/(.+)/?', url)
+        m = re.findall(r'^(?:https?://)?vk.com/([^/]+)/?$', url)
         if not len(m):
             raise ValueError("Url should be started with http://vk.com/")
 
@@ -66,7 +66,7 @@ class VkontakteManager(models.Manager):
             except VkontakteError, e:
                 log.error("Method get_by_slug returned error instead of response. Slug: '%s'. Error: %s" % (slug, e))
                 return None
-            except (KeyError, ValueError), e:
+            except (KeyError, TypeError, ValueError), e:
                 log.error("Method get_by_slug returned response in strange format: %s. Slug is '%s'" % (response, slug))
                 return None
             except AssertionError:
@@ -125,7 +125,9 @@ class VkontakteManager(models.Manager):
         '''
         result = self.get(*args, **kwargs)
         if isinstance(result, list):
-            return self.model.objects.filter(pk__in={self.get_or_create_from_instance(instance).pk for instance in result})
+            # python 2.6 compatibility
+            return self.model.objects.filter(pk__in=set([self.get_or_create_from_instance(instance).pk for instance in result]))
+#            return self.model.objects.filter(pk__in={self.get_or_create_from_instance(instance).pk for instance in result})
         elif isinstance(result, QuerySet):
             return result
         else:
